/*
 * This is part of XmlEditor, a graphical editor for XML files
 * Copyright (C) 2001 CERN - Sebastien Ponce
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contacts :
 *   sebastien.ponce@polytechnique.org
 *   http://lhcb-comp.web.cern.ch/lhcb-comp/
 *   http://www.cern.ch
 */

package ch.cern.lhcb.xmleditor.dtdparser;

import java.io.File;
import java.io.IOException;
import java.io.Reader;

import com.wutka.dtd.DTDParser;

/**
 * CustomDTDParser extends the default DTDParser in order to add the possibility
 * to create a parser on a Reader with a given defaultLocation.
 * 
 * @author Sebastien Ponce
 */

public class CustomDTDParser extends DTDParser {

    /**
     * Creates a parser that will read from the specified Reader object with the
     * specified default location
     * 
     * @param in the Reader
     * @param location the default location
     */
    public CustomDTDParser(Reader in, File location) {
        super(in);
        defaultLocation = location;
    }

    /**
     * Creates a parser that will read from the specified File object
     * 
     * @param in the file to use
     * @throws IOException 
     */
    public CustomDTDParser(File in) throws IOException {
        super(in);
    }

}