/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 * 
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 *  
 */

package com.simulogic.cese.actions;

import java.awt.event.ActionEvent;

import javax.swing.JCheckBoxMenuItem;
import javax.swing.JToggleButton;

import com.simulogic.cese.ModelManager;
import com.simulogic.cese.ResourceManager;
import com.simulogic.utils.ActionSupport;

/**
 * LockRec action implementation
 */
public class LockRecAction extends ActionSupport implements
        java.beans.PropertyChangeListener {

    private ModelManager manager;
    private javax.swing.JToggleButton button;
    private JCheckBoxMenuItem item;
    private boolean state;

    /** 
     * Creates new LockRecAction 
     * 
     * @param m model manager
     */
    public LockRecAction(ModelManager m) {
        this();
        manager = m;
        manager.addPropertyChangeListener(this);
        
        state = manager.getRecordBuilder().getRecNumberField().isEditable();

        button = new javax.swing.JToggleButton(this);
        button.setSelectedIcon(new javax.swing.ImageIcon(this.getClass()
                .getResource(ResourceManager.getResource("lock_rec_image"))));
        button.setSelected(state);

        item = new JCheckBoxMenuItem(this);
        item.setIcon(null);
        item.setSelected(state);
    }

    /** Creates new LockRecAction */
    public LockRecAction() {
        super(ResourceManager.getResource("Lock_Record"), ResourceManager
                .getResource("Lock_current_record"), ResourceManager
                .getResource("unlock_rec_image"));
    }

    /**
     * Returns JToggleButton as a control for action
     * 
     * @return control button
     */
    public JToggleButton getButton() {
        return button;
    }

    /**
     * Returns JCheckBoxMenuItem as a control for action
     * 
     * @return control menu item
     */
    public JCheckBoxMenuItem getItem() {
        return item;
    }

    public void actionPerformed(ActionEvent evt) {
        manager.getRecordBuilder().changeRecLock();
        state = manager.getRecordBuilder().getRecNumberField().isEditable();
        button.setSelected(!state);
        item.setSelected(!state);
    }

    public void propertyChange(java.beans.PropertyChangeEvent evt) {
        if (evt.getPropertyName().equals("record_control"))
            this.setEnabled(((Boolean) evt.getNewValue()).booleanValue());

        if (evt.getPropertyName().equals("lock_control")) {
            button.setSelected(!((Boolean) evt.getNewValue()).booleanValue());
            item.setSelected(!((Boolean) evt.getNewValue()).booleanValue());
        }
    }
}