/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * BeanBuilder code Copyright (C) 2002 Mark Davidson
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.cese.properties;

import java.awt.Component;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.beans.PropertyEditor;
import java.util.Hashtable;

import javax.swing.AbstractCellEditor;
import javax.swing.DefaultCellEditor;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.beaninfo.SwingEditorSupport;
import javax.swing.table.TableCellEditor;

/**
 * An editor for types which have a property editor.
 */
public class PropertyValueEditor extends AbstractCellEditor implements
        TableCellEditor, PropertyChangeListener {

    private PropertyEditor editor;
    private DefaultCellEditor cellEditor;
    private Class type;

    private Hashtable editors;

    /**
     * Default constructor
     */
    public PropertyValueEditor() {
        editors = new Hashtable();
        cellEditor = new DefaultCellEditor(new JTextField());
    }

    /**
     * Get UI for current editor, including custom editor button if applicable.
     */
    public Component getTableCellEditorComponent(JTable table, Object value,
            boolean isSelected, int row, int column) {

        PropertyTableModel model = (PropertyTableModel) table.getModel();
        type = model.getPropertyType(row);

        if (type != null) {
            editor = (PropertyEditor) editors.get(type);
            if (editor == null) {
                PropertyEditor ed = model.getPropertyEditor(row);

                // Make a copy of this prop editor and register this as a
                // prop change listener.
                // We have to do this since we want a unique PropertyEditor
                // instance to be used for an editor vs. a renderer.
                if (ed != null) {
                    Class editorClass = ed.getClass();
                    try {
                        editor = (PropertyEditor) editorClass.newInstance();
                        editor.addPropertyChangeListener(this);
                        editors.put(type, editor);

                    } catch (Exception ex) {
                    }
                }
            }
        } else {
            editor = null;
        }

        if (editor != null) {
            // Special case for the enumerated properties. Must reinitialize
            // to reset the combo box values.
            if (editor instanceof SwingEditorSupport) {
                ((SwingEditorSupport) editor).init(model
                        .getModelPropertyDescriptor(row).getDescriptor());
            }

            editor.setValue(value);

            Component comp = editor.getCustomEditor();
            if (comp != null) {
                comp.setEnabled(isSelected);

                return comp;
            }
        }
        return cellEditor.getTableCellEditorComponent(table, value, isSelected,
                row, column);
    }

    /**
     * Get cellEditorValue for current editor
     */
    public Object getCellEditorValue() {
        Object obj = null;

        if (editor != null) {
            obj = editor.getValue();
        } else {
            obj = cellEditor.getCellEditorValue();
        }

        if (type != null && obj != null && !type.isPrimitive()
                && !type.isAssignableFrom(obj.getClass())) {
            // XXX - debug
            System.out.println("Type mismatch in getCellEditorValue() = "
                    + obj.getClass() + " type = " + type);

            try {
                obj = type.newInstance();
            } catch (Exception ex) {
            }
        }
        return obj;
    }

    //
    // Property Change handler.
    // 

    public void propertyChange(PropertyChangeEvent evt) {
        stopCellEditing();
    }
}