/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.cese.signals;

import java.util.Vector;

/**
 * This is an abstract class for creating signals designed to clamp variable
 * parameters
 */
public abstract class AbstractSignal extends Object {

    /**
     * Vector of signal parameters
     */
    protected Vector parameters = new Vector();

    /**
     * Maximal number of parameters for the signal
     */
    protected int maxParams;

    /**
     * Adds new parameter (duration, amplitude, etc.)
     * 
     * @param par value of parameter
     */
    public void addParameter(double par) {
        if (parameters.size() < maxParams)
                parameters.addElement(new Double(par));
    }

    /**
     * Returns maximum number of parameters for the current signal
     * 
     * @return maximum number of parameters
     */
    public int getMaxParams() {
        return maxParams;
    }

    /**
     * Abstract method for building the signal, you should override it in your
     * classes
     * 
     * @param dt current sampling step, i.e. distance between 2 data points
     * @return resulting array with signal data
     */
    public abstract double[] buildSignal(double dt);

}