/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview.plots;

import java.awt.Graphics2D;
import java.awt.geom.AffineTransform;

import javax.swing.Icon;

import com.simulogic.dataview.DataChannel;

/**
 * Abstract plot is a template for all the different plots
 */
public abstract class AbstractPlot {
	
	/**
     * Distance between the two points on the plot (in user space)
     */
    protected double distance;

    /**
     * Hotspot range for selecting plots by clicking
     */
    protected double hotspot;

    /**
     * Creates new AbstractPlot
     */
    public AbstractPlot() {
        distance = 1.0;
        hotspot = 3.0;
    }

    /**
     * Plots content of the single channel
     * 
     * @param g2 graphics
     * @param xChannel channel containing independent variable values
     * @param yChannel channel containing dependent variable values
     * @param xMin minimal value for plotting range
     * @param xMax maximal value for plotting range
     * @param transform plot transform
     */
    public abstract void plotChannel(Graphics2D g2, DataChannel xChannel,
            DataChannel yChannel, double xMin, double xMax,
            AffineTransform transform);

    /**
     * Determines whether point is located within a plot
     * 
     * @param x point x coordinate
     * @param y point y coordinate
     * @param xChannel channel containing independent variable values
     * @param yChannel channel containing dependent variable values
     * @param transform plot transform
     * 
     * @return true if point belongs to channel
     */
    public abstract boolean isChannelPoint(double x, double y, DataChannel xChannel,
            DataChannel yChannel, AffineTransform transform);

    /**
     * Returns new instance of the plot
     * 
     * @return new instance of the current plot
     */
    public abstract AbstractPlot createPlot();

    /**
     * Getter for property distance.
     * 
     * @return Value of property distance.
     */
    public double getDistance() {
        return distance;
    }

    /**
     * Setter for property distance.
     * 
     * @param distance New value of property distance.
     */
    public void setDistance(double distance) {
        this.distance = distance;
    }
    
    /**
     * Returns plot name.
     * 
     * @return plot name.
     */
    public abstract String getName();
    
    /**
     * Returns small icon for plot.
     * 
     * @return mall icon for plot.
     */
    public abstract Icon getSmallIcon();
    
}