/*
 * @(#)BeanInfoFactory.java	1.4 01/01/04
 *
 * Copyright 2002 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * This software is provided "AS IS," without a warranty of any
 * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
 * WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
 * EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY
 * DAMAGES OR LIABILITIES SUFFERED BY LICENSEE AS A RESULT OF OR
 * RELATING TO USE, MODIFICATION OR DISTRIBUTION OF THIS SOFTWARE OR
 * ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE
 * FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT,
 * SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF
 * THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS
 * BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * 
 * You acknowledge that this software is not designed, licensed or
 * intended for use in the design, construction, operation or
 * maintenance of any nuclear facility.
 */

package javax.swing.beanbuilder;

import java.awt.Image;
import java.beans.BeanInfo;
import java.beans.IntrospectionException;
import java.util.WeakHashMap;

import javax.swing.Icon;
import javax.swing.ImageIcon;

/**
 * A wrapper for the Introspector to generate and return instances of BeanInfos.
 * Creating a BeanInfo with the Introspector is a really expensive operation.
 * Since a BeanInfo is immutable for each class, it makes sense to share
 * instances of BeanInfo's throughout the application.
 * 
 * @version 1.4 01/04/01
 * @author Mark Davidson
 */
public class BeanInfoFactory {

    private static WeakHashMap infos = new WeakHashMap();

    /**
     * Retrieves the BeanInfo for a Class
     */
    public static BeanInfo getBeanInfo(Class cls) {
        BeanInfo beanInfo = (BeanInfo) infos.get(cls);

        if (beanInfo == null) {
            try {
                // We use a custom introspector to get around a problem with
                // deploying Java Web Start. The caching works in
                // the BeanIntrospector but it doesn't hurt to maintain the old
                // architecture.
                beanInfo = BeanIntrospector.getBeanInfo(cls);
                //beanInfo = Introspector.getBeanInfo(cls);
                infos.put(cls, beanInfo);
            } catch (IntrospectionException ex) {
                // XXX - should handle this better.
                ex.printStackTrace();
            }
        }
        return beanInfo;
    }

    /**
     * Retrieves the BeanInfo icon for the class.
     */
    public static Icon getIcon(Class cls) {
        // Note: This should be a static method except that
        // the inner classes can't be static.
        Icon icon = null;

        if (cls == null) return null;

        BeanInfo info = BeanInfoFactory.getBeanInfo(cls);

        if (info != null) {
            Image image = info.getIcon(BeanInfo.ICON_COLOR_16x16);
            if (image != null) {
                icon = new ImageIcon(image);
            } else {
                return getIcon(cls.getSuperclass());
            }
        }
        return icon;
    }

}